cli package
===========

.. toctree::
   :caption: cli package
   :maxdepth: 1
   :hidden:

   cli/class
   cli/command
   cli/decorators
   cli/functions

- :doc:`Cli class <cli/class>`
- :doc:`command module <cli/command>`
- :doc:`Decorators <cli/decorators>`
- :doc:`Functions <cli/functions>`
